package grindhouse

import "flag"
import "fmt"
import "os"

/*
 * Grindhouse
 *
 * Recommended valgrind options:
 * valgrind --xml=yes --xml-file=<file>
 */

func usage() {
	fmt.Fprintf(os.Stderr,
`%s: a valgrind XML file analyzer.
This program analyzes valgrind XML output files and summarizes them.

Usage: %s [opts] [files]
Options:
-h: this help message
`, os.Args[0], os.Args[0])
}

var getHelp = flag.Bool("h", false, "See usage")

func handleFile(filename string) os.Error {
	file, err := os.Open(filename)
	if (err != nil) {
		fmt.Fprintf(os.Stderr, "Failed to open file %s\n", filename)
		return err
	}
	defer file.Close()
	vinfo, err := ParseValgrindXml(file)
	if (err != nil) {
		fmt.Fprintf(os.Stderr, "Failed to parse file %s\n", filename)
		return err
	}
	if !vinfo.Clean {
		return os.EAFNOSUPPORT
	}
	return nil
}

func main() {
	ret := 0
	flag.Usage = usage
	flag.Parse()
	if (*getHelp) {
		usage()
		os.Exit(0)
	}
	filenames := make([]string, flag.NArg())
	for i := 0; i < flag.NArg(); i++ {
		filenames[i] = flag.Arg(i)
	}
	if (flag.NArg() == 0) {
		fmt.Fprintf(os.Stderr, "You must give at least one file to open as an argument.")
		usage()
		os.Exit(1)
	}
	for i := 0; i < len(filenames); i++ {
		if handleFile(filenames[i]) != nil {
			ret = 1
		}
	}
	if (ret != 0) {
		fmt.Fprintf(os.Stderr, "Errors were encountered.")
	}
	os.Exit(ret)
}
